michromer::client

Struct LevelClient

pub struct LevelClient<T: HttpClient + Clone> {
    pub level: Level,
    pub base_url: String,
    /* private fields */
}
Stockfighter client for a specific level. The stock api is defined here It’s wrapper around an http client. As such it can return errors for parsing or for network issues.

Fields

level: Levelbase_url: String

Implementations

Source

impl<T: HttpClient + Clone> LevelClient<T>

pub fn heart_beat(&self) -> Result<HeartBeatResponse>

See if this Level is up.

This should really only be used to sanity check that the level hasn’t been torn down.

pub fn venue_heart_beat(&self, venue: &str) -> Result<VenueHeartBeatResponse>

Check if a venue is ok.

pub fn stock_list(&self, venue: &str) -> Result<StockListResponse>

Get a list of all the stocks this venue can accept trades for.

Errors

Errors out when: http fails parsing fails

pub fn orderbook(&self, venue: &str, stock: &str) -> Result<OrderbookResponse>

Get a copy of the venue’s order book. Stockfighter suggests that this will be a slow operation that should be done as little as possible.

pub fn quote(&self, venue: &str, stock: &str) -> Result<QuoteResponse>

Ask a venue about the current state of a stock.

pub fn order(&self, o: &Order) -> Result<OrderResponse>

Send in an order, and get back a response.

pub fn order_status( &self, venue: &str, stock: &str, id: u64, ) -> Result<OrderResponse>

Find out how a specific order on a specific venue is doing.

pub fn delete_order( &self, venue: &str, stock: &str, id: u64, ) -> Result<OrderResponse>

Try and cancel an order.

pub fn new(http_client: T, level: Level, base_url: &str) -> LevelClient<T>

Constructs a new level client.